Protox v0.12.0 Protox.Default
Default values of Protocol Buffers types. For protobuf2, it’s useful to
get the default values which have been set to nil, that is which were not
present on the wire.
Summary
Functions
Returns the default value of a Protocol Buffer type specified with an atom